@@ -5,12 +5,13 @@ from rich.console import Console
 from rich.panel import Panel
 
 from instant_python import __version__
+from instant_python.cli.instant_python_typer import InstantPythonTyper
 from instant_python.config.delivery import cli as config
 from instant_python.initialize.delivery import cli as init
+from instant_python.metrics.delivery.metrics_middleware import MetricsMiddleware
 from instant_python.shared.application_error import ApplicationError
-from instant_python.cli.instant_python_typer import InstantPythonTyper
 
-app = InstantPythonTyper()
+app = InstantPythonTyper(cls=MetricsMiddleware)
 console = Console()
 
 
@@ -22,6 +23,7 @@ def version_callback(value: bool) -> None:
 
 @app.callback(invoke_without_command=True)
 def main(
+    ctx: typer.Context,
     version: Annotated[
         bool | None,
         typer.Option(
@@ -32,7 +34,9 @@ def main(
             is_eager=True,
         ),
     ] = None,
-) -> None: ...  # The version_callback will handle the version display
+) -> None:
+    if ctx.invoked_subcommand is None:
+        console.print(ctx.get_help())
 
 
 app.add_typer(init.app)
