@@ -6,7 +6,7 @@ from instant_python.initialize.application.project_initializer import ProjectIni
 from instant_python.initialize.infra.env_manager.env_manager_factory import EnvManagerFactory
 from instant_python.initialize.infra.env_manager.system_console import SystemConsole
 from instant_python.initialize.infra.formatter.ruff_project_formatter import RuffProjectFormatter
-from instant_python.initialize.infra.persistence.yaml_config_repository import YamlConfigRepository
+from instant_python.shared.infra.persistence.yaml_config_repository import YamlConfigRepository
 from instant_python.initialize.infra.renderer.jinja_environment import JinjaEnvironment
 from instant_python.initialize.infra.renderer.jinja_project_renderer import JinjaProjectRenderer
 from instant_python.initialize.infra.version_control.git_configurer import GitConfigurer
