@@ -1,12 +1,12 @@
-{% set template_domain_import = "shared.domain"|compute_base_path(template.name) %}
-from {{ general.source_name }}.{{ template_domain_import }}.event.domain_event import DomainEvent
-from {{ general.source_name }}.{{ template_domain_import }}.value_objects.aggregate import Aggregate
+from sindripy.value_objects import Aggregate
+from {{ general.source_name }}{{ "shared.domain.event.domain_event" | resolve_import_path(template.name) }} import DomainEvent
 
 
 class EventAggregate(Aggregate):
     _domain_events: list[DomainEvent]
 
     def __init__(self) -> None:
+        super().__init__()
         self._domain_events = []
 
     def record(self, event: DomainEvent) -> None:
