@@ -1,13 +1,8 @@
-{% set template_infra_import = "shared.infra"|compute_base_path(template.name) %}
 from collections.abc import AsyncGenerator
 import pytest
 from sqlalchemy.ext.asyncio import AsyncEngine, create_async_engine
 
-{% if template_infra_import %}
-from {{ general.source_name }}.{{ template_infra_import }}.persistence.sqlalchemy.postgres_settings import PostgresSettings
-{% else %}
-from {{ general.source_name }}.persistence.sqlalchemy.postgres_settings import PostgresSettings
-{% endif %}
+from {{ general.source_name }}{{ "shared.infra.persistence.postgres_settings" | resolve_import_path(template.name) }} import PostgresSettings
 
 
 @pytest.fixture
